==> kubernetes-model-3.0.1-sources.jar: io/fabric8/kubernetes/api/model/PodBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodBuilder extends PodFluentImpl<PodBuilder> implements VisitableBuilder<Pod,PodBuilder>{

    PodFluent<?> fluent;
    Boolean validationEnabled;

    public PodBuilder(){
            this(true);
    }
    public PodBuilder(Boolean validationEnabled){
            this(new Pod(), validationEnabled);
    }
    public PodBuilder(PodFluent<?> fluent){
            this(fluent, true);
    }
    public PodBuilder(PodFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Pod(), validationEnabled);
    }
    public PodBuilder(PodFluent<?> fluent,Pod instance){
            this(fluent, instance, true);
    }
    public PodBuilder(PodFluent<?> fluent,Pod instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSpec(instance.getSpec()); 
            fluent.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }
    public PodBuilder(Pod instance){
            this(instance,true);
    }
    public PodBuilder(Pod instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }

    public Pod build(){
            Pod buildable = new Pod(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodBuilder that = (PodBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.5.0-sources.jar: io/fabric8/kubernetes/api/model/PodBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class PodBuilder extends PodFluentImpl<PodBuilder> implements VisitableBuilder<Pod,PodBuilder>{

    PodFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public PodBuilder(){
            this(true);
    }
    public PodBuilder(Boolean validationEnabled){
            this(new Pod(), validationEnabled);
    }
    public PodBuilder(PodFluent<?> fluent){
            this(fluent, true);
    }
    public PodBuilder(PodFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Pod(), validationEnabled);
    }
    public PodBuilder(PodFluent<?> fluent,Pod instance){
            this(fluent, instance, true);
    }
    public PodBuilder(PodFluent<?> fluent,Pod instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSpec(instance.getSpec()); 
            fluent.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }
    public PodBuilder(Pod instance){
            this(instance,true);
    }
    public PodBuilder(Pod instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }
    public PodBuilder(Validator validator){
            this(new Pod(), true);
    }
    public PodBuilder(PodFluent<?> fluent,Pod instance,Validator validator){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSpec(instance.getSpec()); 
            fluent.withStatus(instance.getStatus()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public PodBuilder(Pod instance,Validator validator){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public Pod build(){
            Pod buildable = new Pod(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodBuilder that = (PodBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
